# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/business/snapshot_manage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#live/business/snapshot_manage.proto\x12\x1fVolcengine.Live.Models.Business\"\x92\x01\n\x12\x43\x44NSnapshotHistory\x12\r\n\x05Vhost\x18\x01 \x01(\t\x12\x0b\n\x03\x41pp\x18\x02 \x01(\t\x12\x0e\n\x06Stream\x18\x03 \x01(\t\x12\x0c\n\x04Path\x18\x04 \x01(\t\x12\x10\n\x08\x46ileSize\x18\x05 \x01(\x02\x12\x11\n\tTimeStamp\x18\x06 \x01(\t\x12\r\n\x05Width\x18\x07 \x01(\x03\x12\x0e\n\x06Height\x18\x08 \x01(\x03\"V\n\nPagination\x12\x0f\n\x07PageCur\x18\x01 \x01(\x03\x12\x10\n\x08PageSize\x18\x02 \x01(\x03\x12\x11\n\tPageTotal\x18\x03 \x01(\x03\x12\x12\n\nTotalCount\x18\x04 \x01(\x03\"\x9c\x01\n\x16\x43\x44NSnapshotHistoryInfo\x12\x41\n\x04\x44\x61ta\x18\x01 \x03(\x0b\x32\x33.Volcengine.Live.Models.Business.CDNSnapshotHistory\x12?\n\nPagination\x18\x02 \x03(\x0b\x32+.Volcengine.Live.Models.Business.PaginationB\xd6\x01\n*com.volcengine.service.live.model.businessB\x0eSnapshotManageP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02!Volc\\Service\\Live\\Models\\Business\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_CDNSNAPSHOTHISTORY = DESCRIPTOR.message_types_by_name['CDNSnapshotHistory']
_PAGINATION = DESCRIPTOR.message_types_by_name['Pagination']
_CDNSNAPSHOTHISTORYINFO = DESCRIPTOR.message_types_by_name['CDNSnapshotHistoryInfo']
CDNSnapshotHistory = _reflection.GeneratedProtocolMessageType('CDNSnapshotHistory', (_message.Message,), {
  'DESCRIPTOR' : _CDNSNAPSHOTHISTORY,
  '__module__' : 'live.business.snapshot_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.CDNSnapshotHistory)
  })
_sym_db.RegisterMessage(CDNSnapshotHistory)

Pagination = _reflection.GeneratedProtocolMessageType('Pagination', (_message.Message,), {
  'DESCRIPTOR' : _PAGINATION,
  '__module__' : 'live.business.snapshot_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.Pagination)
  })
_sym_db.RegisterMessage(Pagination)

CDNSnapshotHistoryInfo = _reflection.GeneratedProtocolMessageType('CDNSnapshotHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _CDNSNAPSHOTHISTORYINFO,
  '__module__' : 'live.business.snapshot_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.CDNSnapshotHistoryInfo)
  })
_sym_db.RegisterMessage(CDNSnapshotHistoryInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.businessB\016SnapshotManageP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\240\001\001\330\001\001\302\002\000\312\002!Volc\\Service\\Live\\Models\\Business\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _CDNSNAPSHOTHISTORY._serialized_start=73
  _CDNSNAPSHOTHISTORY._serialized_end=219
  _PAGINATION._serialized_start=221
  _PAGINATION._serialized_end=307
  _CDNSNAPSHOTHISTORYINFO._serialized_start=310
  _CDNSNAPSHOTHISTORYINFO._serialized_end=466
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/business/VQScore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1blive/business/VQScore.proto\x12\x1fVolcengine.Live.Models.Business\"\x17\n\tVQScoreID\x12\n\n\x02ID\x18\x01 \x01(\t\"-\n\tScoreInfo\x12\x11\n\tPointTime\x18\x01 \x01(\t\x12\r\n\x05Score\x18\x02 \x01(\x02\"d\n\rAddrScoreInfo\x12\x10\n\x08\x41\x64\x64rType\x18\x01 \x01(\x03\x12\x41\n\rScoreInfoList\x18\x02 \x03(\x0b\x32*.Volcengine.Live.Models.Business.ScoreInfo\"\x88\x02\n\x0bVQScoreInfo\x12\x10\n\x08MainAddr\x18\x01 \x01(\t\x12\x14\n\x0c\x43ontrastAddr\x18\x02 \x01(\t\x12\x10\n\x08\x44uration\x18\x03 \x01(\x03\x12\x15\n\rTotalPointNum\x18\x04 \x01(\x03\x12\x18\n\x10MainAverageScore\x18\x05 \x01(\x02\x12\x1c\n\x14\x43ontrastAverageScore\x18\x06 \x01(\x02\x12\x12\n\nDifference\x18\x07 \x01(\x02\x12\x15\n\rDifferencePer\x18\x08 \x01(\x02\x12\x45\n\rAddrScoreList\x18\t \x03(\x0b\x32..Volcengine.Live.Models.Business.AddrScoreInfo\"R\n\x0fVQScoreTaskInfo\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x10\n\x08\x44uration\x18\x02 \x01(\x03\x12\x0e\n\x06Status\x18\x03 \x01(\x03\x12\x11\n\tAccountID\x18\x04 \x01(\t\"\x8c\x01\n\x13VQScoreTaskListInfo\x12\x11\n\tStartTime\x18\x02 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x03 \x01(\t\x12\r\n\x05Total\x18\x04 \x01(\x03\x12\x42\n\x08TaskList\x18\x05 \x03(\x0b\x32\x30.Volcengine.Live.Models.Business.VQScoreTaskInfoB\xcf\x01\n*com.volcengine.service.live.model.businessB\x07VQScoreP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02!Volc\\Service\\Live\\Models\\Business\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_VQSCOREID = DESCRIPTOR.message_types_by_name['VQScoreID']
_SCOREINFO = DESCRIPTOR.message_types_by_name['ScoreInfo']
_ADDRSCOREINFO = DESCRIPTOR.message_types_by_name['AddrScoreInfo']
_VQSCOREINFO = DESCRIPTOR.message_types_by_name['VQScoreInfo']
_VQSCORETASKINFO = DESCRIPTOR.message_types_by_name['VQScoreTaskInfo']
_VQSCORETASKLISTINFO = DESCRIPTOR.message_types_by_name['VQScoreTaskListInfo']
VQScoreID = _reflection.GeneratedProtocolMessageType('VQScoreID', (_message.Message,), {
  'DESCRIPTOR' : _VQSCOREID,
  '__module__' : 'live.business.VQScore_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.VQScoreID)
  })
_sym_db.RegisterMessage(VQScoreID)

ScoreInfo = _reflection.GeneratedProtocolMessageType('ScoreInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCOREINFO,
  '__module__' : 'live.business.VQScore_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.ScoreInfo)
  })
_sym_db.RegisterMessage(ScoreInfo)

AddrScoreInfo = _reflection.GeneratedProtocolMessageType('AddrScoreInfo', (_message.Message,), {
  'DESCRIPTOR' : _ADDRSCOREINFO,
  '__module__' : 'live.business.VQScore_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.AddrScoreInfo)
  })
_sym_db.RegisterMessage(AddrScoreInfo)

VQScoreInfo = _reflection.GeneratedProtocolMessageType('VQScoreInfo', (_message.Message,), {
  'DESCRIPTOR' : _VQSCOREINFO,
  '__module__' : 'live.business.VQScore_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.VQScoreInfo)
  })
_sym_db.RegisterMessage(VQScoreInfo)

VQScoreTaskInfo = _reflection.GeneratedProtocolMessageType('VQScoreTaskInfo', (_message.Message,), {
  'DESCRIPTOR' : _VQSCORETASKINFO,
  '__module__' : 'live.business.VQScore_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.VQScoreTaskInfo)
  })
_sym_db.RegisterMessage(VQScoreTaskInfo)

VQScoreTaskListInfo = _reflection.GeneratedProtocolMessageType('VQScoreTaskListInfo', (_message.Message,), {
  'DESCRIPTOR' : _VQSCORETASKLISTINFO,
  '__module__' : 'live.business.VQScore_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.VQScoreTaskListInfo)
  })
_sym_db.RegisterMessage(VQScoreTaskListInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.businessB\007VQScoreP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\240\001\001\330\001\001\302\002\000\312\002!Volc\\Service\\Live\\Models\\Business\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _VQSCOREID._serialized_start=64
  _VQSCOREID._serialized_end=87
  _SCOREINFO._serialized_start=89
  _SCOREINFO._serialized_end=134
  _ADDRSCOREINFO._serialized_start=136
  _ADDRSCOREINFO._serialized_end=236
  _VQSCOREINFO._serialized_start=239
  _VQSCOREINFO._serialized_end=503
  _VQSCORETASKINFO._serialized_start=505
  _VQSCORETASKINFO._serialized_end=587
  _VQSCORETASKLISTINFO._serialized_start=590
  _VQSCORETASKLISTINFO._serialized_end=730
# @@protoc_insertion_point(module_scope)



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService
from volcengine.live.models.request.live_requests import GeneratePushURLRequest

if __name__ == '__main__':
    live_service = LiveService()
    live_service.set_ak('')
    live_service.set_sk('')
    req = GeneratePushURLRequest()
    req.Vhost = ''
    req.App = ''
    req.Stream = ''
    req.ValidDuration = 0
    req.ExpiredTime = ''

    print(req)
    resp = live_service.generate_push_u_r_l(req)
    print(resp)


#  -*- coding: utf-8 -*-
import os
import sys

sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../../")

from volcengine.example.dcdn import ak, sk
from volcengine.dcdn.DCDNService import DCDNService

if __name__ == '__main__':
    svc = DCDNService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    svc.set_ak(ak)
    svc.set_sk(sk)

    body = [
        {
            "Domain": "www.test.com",
            "Origin": {
                "Origins": [
                    {
                        "Name": "1.1.1.1",
                        "Weight": 1
                    }
                ],
                "OriginType": "IP",
                "OriginProtocolType": "http",
            },
        }
    ]

    resp = svc.update_domain_config(body)
    print(resp)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_apps_manage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"vod/business/vod_apps_manage.proto\x12\x1eVolcengine.Vod.Models.Business\"Z\n\x13VodGetAppInfoResult\x12\r\n\x05\x41ppId\x18\x01 \x01(\x04\x12\x0e\n\x06Scheme\x18\x02 \x01(\t\x12\x11\n\tAppEnName\x18\x03 \x01(\t\x12\x11\n\tAppCnName\x18\x04 \x01(\tB\xd1\x01\n)com.volcengine.service.vod.model.businessB\rVodAppsManageP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_VODGETAPPINFORESULT = DESCRIPTOR.message_types_by_name['VodGetAppInfoResult']
VodGetAppInfoResult = _reflection.GeneratedProtocolMessageType('VodGetAppInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODGETAPPINFORESULT,
  '__module__' : 'vod.business.vod_apps_manage_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodGetAppInfoResult)
  })
_sym_db.RegisterMessage(VodGetAppInfoResult)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\rVodAppsManageP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODGETAPPINFORESULT._serialized_start=70
  _VODGETAPPINFORESULT._serialized_end=160
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: live/business/pull_to_push.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from volcengine.live.models.business import snapshot_manage_pb2 as live_dot_business_dot_snapshot__manage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n live/business/pull_to_push.proto\x12\x1fVolcengine.Live.Models.Business\x1a#live/business/snapshot_manage.proto\",\n\x1a\x43reatePullToPushTaskResult\x12\x0e\n\x06TaskId\x18\x01 \x01(\t\"\x98\x01\n\x18ListPullToPushTaskResult\x12;\n\x04List\x18\x01 \x03(\x0b\x32-.Volcengine.Live.Models.Business.TaskInfoItem\x12?\n\nPagination\x18\x02 \x01(\x0b\x32+.Volcengine.Live.Models.Business.Pagination\"\xdf\x01\n\x0cTaskInfoItem\x12\r\n\x05Title\x18\x01 \x01(\t\x12\x0e\n\x06TaskId\x18\x02 \x01(\t\x12\x11\n\tStartTime\x18\x03 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x04 \x01(\t\x12\x13\n\x0b\x43\x61llbackURL\x18\x05 \x01(\t\x12\x0c\n\x04Type\x18\x06 \x01(\x05\x12\x11\n\tCycleMode\x18\x07 \x01(\x05\x12\x0f\n\x07\x44stAddr\x18\x08 \x01(\t\x12\x0f\n\x07SrcAddr\x18\t \x01(\t\x12\x10\n\x08SrcAddrS\x18\n \x03(\t\x12\x0e\n\x06Status\x18\x0b \x01(\t\x12\x12\n\nTaskStatus\x18\x0c \x01(\x05\x42\xd6\x01\n*com.volcengine.service.live.model.businessB\x0ePullToPushTaskP\x01ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02!Volc\\Service\\Live\\Models\\Business\xe2\x02$Volc\\Service\\Live\\Models\\GPBMetadatab\x06proto3')



_CREATEPULLTOPUSHTASKRESULT = DESCRIPTOR.message_types_by_name['CreatePullToPushTaskResult']
_LISTPULLTOPUSHTASKRESULT = DESCRIPTOR.message_types_by_name['ListPullToPushTaskResult']
_TASKINFOITEM = DESCRIPTOR.message_types_by_name['TaskInfoItem']
CreatePullToPushTaskResult = _reflection.GeneratedProtocolMessageType('CreatePullToPushTaskResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPULLTOPUSHTASKRESULT,
  '__module__' : 'live.business.pull_to_push_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.CreatePullToPushTaskResult)
  })
_sym_db.RegisterMessage(CreatePullToPushTaskResult)

ListPullToPushTaskResult = _reflection.GeneratedProtocolMessageType('ListPullToPushTaskResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTPULLTOPUSHTASKRESULT,
  '__module__' : 'live.business.pull_to_push_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.ListPullToPushTaskResult)
  })
_sym_db.RegisterMessage(ListPullToPushTaskResult)

TaskInfoItem = _reflection.GeneratedProtocolMessageType('TaskInfoItem', (_message.Message,), {
  'DESCRIPTOR' : _TASKINFOITEM,
  '__module__' : 'live.business.pull_to_push_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Live.Models.Business.TaskInfoItem)
  })
_sym_db.RegisterMessage(TaskInfoItem)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.volcengine.service.live.model.businessB\016PullToPushTaskP\001ZBgithub.com/volcengine/volc-sdk-golang/service/live/models/business\240\001\001\330\001\001\302\002\000\312\002!Volc\\Service\\Live\\Models\\Business\342\002$Volc\\Service\\Live\\Models\\GPBMetadata'
  _CREATEPULLTOPUSHTASKRESULT._serialized_start=106
  _CREATEPULLTOPUSHTASKRESULT._serialized_end=150
  _LISTPULLTOPUSHTASKRESULT._serialized_start=153
  _LISTPULLTOPUSHTASKRESULT._serialized_end=305
  _TASKINFOITEM._serialized_start=308
  _TASKINFOITEM._serialized_end=531
# @@protoc_insertion_point(module_scope)
